kwimage.structs package
=======================

Submodules
----------

.. toctree::
   :maxdepth: 4

   kwimage.structs._generic
   kwimage.structs.boxes
   kwimage.structs.coords
   kwimage.structs.detections
   kwimage.structs.heatmap
   kwimage.structs.mask
   kwimage.structs.points
   kwimage.structs.polygon
   kwimage.structs.segmentation
   kwimage.structs.single_box

Module contents
---------------

.. automodule:: kwimage.structs
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
